@@ -1,6 +1,6 @@
 pub mod storage;
 
-mod lmdb_storage;
+pub mod lmdb_storage;
 mod tt_storage;
 
 pub mod remote_storage_client;
